<?php

namespace Drupal\new_relic_insights\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class NewRelicInsightsSettingsForm.
 */
class NewRelicInsightsSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'new_relic_insights.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'new_relic_insights_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('new_relic_insights.settings');

    $form['base_url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('New Relic base url'),
      '#description' => $this->t('The base url of the Insights API.'),
      '#required' => TRUE,
      '#default_value' => $config->get('base_url'),
    ];

    $form['account_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('New Relic Account ID'),
      '#description' => $this->t('The account number associated with your Insights account.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('account_id'),
    ];

    $form['insert_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Insert API Key'),
      '#description' => $this->t('An Insert Key generated for your Insights account.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('insert_key'),
    ];

    $form['curl_timeout'] = [
      '#type' => 'number',
      '#title' => $this->t('Timeout'),
      '#default_value' => $config->get('curl_timeout'),
      '#description' => $this->t('Specifies the maximum time - in seconds - to keep the curl connection open.'),
      '#min' => 1,
    ];

    $form['user_agent'] = [
      '#type' => 'textfield',
      '#title' => $this->t('User agent'),
      '#description' => $this->t('The user agent used to decorate NR insight records.'),
      '#default_value' => $config->get('user_agent'),
    ];

    $form['collect_watchdog'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable watchdog integration'),
      '#default_value' => $config->get('collect_watchdog'),
    ];

    $form['collect_better_statistics'] = [
      '#markup' => $this->t(
        'SAPI integration can be enabled on the <a href="@sapi_admin">plugin admin</a> page by enabling the "New Relic Insights Entity Interaction Handler" plugin.',
        ['@sapi_admin' => '/admin/config/sapi/statistics-plugins']
      ),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('new_relic_insights.settings');

    // Get form values (excluding entity type and bundle keys)
    $values = $form_state->cleanValues()->getValues();

    // Save the values in the config file.
    foreach ($values as $key => $value) {
      $config->set($key, $value);
    }
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
