<?php

namespace Drupal\Tests\new_relic_insights\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Symfony\Component\HttpFoundation\Request;

/**
 * Test new_relic_insights logger functionality.
 *
 * @group new_relic_insights
 */
class NewRelicInsightsTest extends KernelTestBase {

  public static $modules = ['new_relic_insights', 'new_relic_insights_test'];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->installConfig(['new_relic_insights']);
  }

  /**
   * Tests the NR insights integration for watchdog (i.e. logging messages).
   */
  public function testLogger() {
    /** @var \Drupal\Core\Config\Config $config */
    $config = $this->container->get('config.factory')->getEditable('new_relic_insights.settings');
    $config->set('collect_watchdog', TRUE);
    $config->save();

    $request = Request::create('/page-not-found', 'GET', [], [], [], ['REMOTE_ADDR' => '1.2.3.4']);
    $request->headers->set('Referer', 'other-site');
    \Drupal::requestStack()->push($request);

    $user = $this->getMockBuilder('Drupal\Core\Session\AccountInterface')->getMock();
    $user->method('getEmail')->willReturn('test@test.com');
    $this->container->set('current_user', $user);

    \Drupal::logger('my_module')->warning('My warning message with @placeholder.', [
      'link' => '/my-link',
      '@placeholder' => 'REPLACEMENT',
    ]);

    $log_filename = $this->container->get('file_system')->realpath('public://new_relic_insights.log');
    $logs = explode(PHP_EOL, file_get_contents($log_filename));
    $log = explode('|', $logs[0]);

    global $base_url;
    // Type.
    $this->assertEquals('my_module', $log[1]);
    // User.
    $this->assertEquals($user->getEmail(), $log[2]);
    // Message.
    $this->assertEquals('My warning message with @placeholder.', $log[3]);
    // Full Message.
    $this->assertEquals('My warning message with REPLACEMENT.', $log[4]);
    // Severity.
    $this->assertEquals(4, $log[5]);
    // Link.
    $this->assertEquals('/my-link', $log[6]);
    // Location.
    $this->assertEquals($base_url . '/page-not-found', $log[7]);
    // Referrer.
    $this->assertEquals('other-site', $log[8]);
    // Hostname.
    $this->assertEquals('1.2.3.4', $log[9]);
  }

}
